      subroutine su3mult_m_mh_m(am1,am2,rm) ! Bernd Berg Mar 02 2008.
c Alexei Bazavov Oct 20 2005. Multiply SU(3) matrix (m) by conjugate
C                           matrix (mh) and put result in matrix (m).
c am1 -- matrix 1
c am2 -- matrix 2
c rm -- resulting matrix
      include '../../Libs/Fortran/implicit.sta'
      include '../../Libs/Fortran/constants.par'
      dimension am1(1:18),am2(1:18),rm(1:18),am3(1:18)

c TEMPORARY SOLUTION

c make hermitian conjugate
      am3(1)=am2(1)
      am3(2)=am2(4)
      am3(3)=am2(7)
      am3(4)=am2(2)
      am3(5)=am2(5)
      am3(6)=am2(8)
      am3(7)=am2(3)
      am3(8)=am2(6)
      am3(9)=am2(9)
      am3(10)=-am2(10)
      am3(11)=-am2(13)
      am3(12)=-am2(16)
      am3(13)=-am2(11)
      am3(14)=-am2(14)
      am3(15)=-am2(17)
      am3(16)=-am2(12)
      am3(17)=-am2(15)
      am3(18)=-am2(18)

c multiply
      call su3mult_m_m_m(am1,am3,rm)

      return
      end
